Package: HiddenMarkov
Title: Hidden Markov Models
Version: 1.8-14
Date: 2025-02-28
Authors@R: person(given = "David",
                    family = "Harte",
                    role = c("aut", "cre"),
                    email = "d.s.harte@gmail.com")
Description: Contains functions for the analysis of Discrete Time Hidden Markov Models, Markov Modulated GLMs and the Markov Modulated Poisson Process. It includes functions for simulation, parameter estimation, and the Viterbi algorithm. See the topic "HiddenMarkov" for an introduction to the package, and "Change Log" for a list of recent changes. The algorithms are based of those of Walter Zucchini.
Suggests: parallel
License: GPL (>= 2)
URL: https://www.statsresearch.co.nz/dsh/sslib/
NeedsCompilation: yes
Packaged: 2025-01-28 00:52:38 UTC; david
Author: David Harte [aut, cre]
Maintainer: David Harte <d.s.harte@gmail.com>
Repository: CRAN
Date/Publication: 2025-01-28 20:30:03 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-01-28 21:40:07 UTC; unix
Archs: HiddenMarkov.so.dSYM
